==> bytedesk_kefu-0.6.2.tar.gz: lib/blocs/thread_bloc/thread_event.dart <==
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

@immutable
abstract class ThreadEvent extends Equatable {
  const ThreadEvent();

  @override
  List<Object> get props => [];
}

class InitThreadEvent extends ThreadEvent {}

class RefreshThreadEvent extends ThreadEvent {}

class RefreshHistoryThreadEvent extends ThreadEvent {
  final int page;
  final int size;
  //
  RefreshHistoryThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadEvent extends ThreadEvent {
  final int page;
  final int size;
  //
  RefreshVisitorThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadAllEvent extends ThreadEvent {
  //
  RefreshVisitorThreadAllEvent()
      : super();
}

class UpdateThreadEvent extends ThreadEvent {
  final String tid;

  UpdateThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

class DeleteThreadEvent extends ThreadEvent {
  final String tid;

  DeleteThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

// 请求客服会话
class RequestThreadEvent extends ThreadEvent {
  final String wid;
  final String type;
  final String aid;

  RequestThreadEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

// 请求人工客服，不管此工作组是否设置为默认机器人，只要有人工客服在线，则可以直接对接人工
class RequestAgentEvent extends ThreadEvent {
  final String wid;
  final String type;
  final String aid;

  RequestAgentEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

class RequestContactThreadEvent extends ThreadEvent {
  final String cid;

  RequestContactThreadEvent(
      {@required this.cid})
      : super();
}

class RequestGroupThreadEvent extends ThreadEvent {
  final String gid;

  RequestGroupThreadEvent(
      {@required this.gid})
      : super();
}

==> bytedesk_kefu-1.0.4.tar.gz: lib/blocs/thread_bloc/thread_event.dart <==
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

@immutable
abstract class ThreadEvent extends Equatable {
  const ThreadEvent();

  @override
  List<Object> get props => [];
}

class InitThreadEvent extends ThreadEvent {}

class RefreshThreadEvent extends ThreadEvent {}

class RefreshHistoryThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  RefreshHistoryThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadEvent extends ThreadEvent {
  final int? page;
  final int? size;
  //
  RefreshVisitorThreadEvent({@required this.page, @required this.size})
      : super();
}

class RefreshVisitorThreadAllEvent extends ThreadEvent {
  //
  RefreshVisitorThreadAllEvent() : super();
}

class UpdateThreadEvent extends ThreadEvent {
  final String? tid;

  UpdateThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

class DeleteThreadEvent extends ThreadEvent {
  final String? tid;

  DeleteThreadEvent({@required this.tid})
      : assert(tid != null),
        super();
}

// 请求客服会话
class RequestThreadEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;

  RequestThreadEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

// 请求人工客服，不管此工作组是否设置为默认机器人，只要有人工客服在线，则可以直接对接人工
class RequestAgentEvent extends ThreadEvent {
  final String? wid;
  final String? type;
  final String? aid;

  RequestAgentEvent(
      {@required this.wid, @required this.type, @required this.aid})
      : super();
}

class RequestContactThreadEvent extends ThreadEvent {
  final String? cid;

  RequestContactThreadEvent({@required this.cid}) : super();
}

class RequestGroupThreadEvent extends ThreadEvent {
  final String? gid;

  RequestGroupThreadEvent({@required this.gid}) : super();
}
